"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var $ = require("jquery");
var R = require("ramda");
window.jQuery = $; // Needed to signalr
require("signalr");
var BPromise = require("bluebird");
var inversify_1 = require("inversify");
var ts_smart_logger_1 = require("ts-smart-logger");
var definitions_interface_1 = require("../../definitions.interface");
var base_channel_service_1 = require("../base-channel.service");
var util_1 = require("../../util");
var channel_interface_1 = require("../channel.interface");
var SignalRChannel = /** @class */ (function (_super) {
    __extends(SignalRChannel, _super);
    /**
     * @stable [12.12.2018]
     */
    function SignalRChannel() {
        var _this = _super.call(this) || this;
        _this.signalRInitTasks = new Map();
        _this.onMessage = _this.onMessage.bind(_this);
        _this.toChannelClient = _this.toChannelClient.bind(_this);
        return _this;
    }
    SignalRChannel_1 = SignalRChannel;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {ISignalRChannelConfigEntity} config
     */
    SignalRChannel.prototype.connect = function (ip, config) {
        var _this = this;
        var hubUrl = "" + this.settings.signalRUrl + ip;
        // We need to load the script at the any case
        this.signalRScriptTask = this.signalRScriptTask || util_1.createScript({ src: hubUrl + "?_dc=" + Date.now() });
        this.cancelInitTask(ip);
        this.signalRInitTasks.set(ip, 
        // Need to wrap the script loader promise because of chain cancellation
        new BPromise(function (resolve) { return _this.signalRScriptTask.then(resolve); }) // This new promise instance may be canceled!
            .then(function () { return _this.onSignalRInitialize(ip, hubUrl, config); }));
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     */
    SignalRChannel.prototype.disconnect = function (ip) {
        this.cancelInitTask(ip);
        this.unregisterClient(ip);
    };
    /**
     * @stable [12.12.2018]
     * @param {string} ip
     * @param {string} hubUrl
     * @param {ISignalRChannelConfigEntity} config
     */
    SignalRChannel.prototype.onSignalRInitialize = function (ip, hubUrl, config) {
        var onMessage = this.onMessage;
        var toChannelClient = this.toChannelClient;
        var areSpecificChannelsPresent = !R.isNil(config) && util_1.isArrayNotEmpty(config.channels);
        $.connection.hub.url = hubUrl;
        if (!R.isNil(config) && util_1.isFn(config.query)) {
            $.connection.hub.qs = util_1.toType(config.query)();
        }
        Reflect.set($.connection.hub, 'baseUrl', this.settings.signalRUrl);
        var disconnectCallback;
        var isDisconnected = false;
        this.registerClient(ip, {
            on: function (event, callback) {
                switch (event) {
                    case channel_interface_1.CHANNEL_CONNECT_EVENT:
                        if (areSpecificChannelsPresent) {
                            config.channels.forEach(function (channel) {
                                var specificChannel = toChannelClient(channel, channel_interface_1.CHANNEL_CONNECT_EVENT);
                                if (!R.isNil(specificChannel)) {
                                    specificChannel.on('addmessage', function () { });
                                }
                            });
                        }
                        $.connection.hub.start(config && config.transport ? { transport: config.transport } : {})
                            .done(function () {
                            if (!isDisconnected) {
                                callback();
                                $.connection.hub.received(function (data) { return onMessage(ip, definitions_interface_1.UNDEF, data); });
                            }
                        });
                        break;
                    case channel_interface_1.CHANNEL_DISCONNECT_EVENT:
                        disconnectCallback = function () {
                            isDisconnected = true;
                            callback();
                        };
                        break;
                }
            },
            emit: function (event) {
                var args = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                    args[_i - 1] = arguments[_i];
                }
                var _a;
                switch (event) {
                    case channel_interface_1.CHANNEL_SEND_EVENT:
                        try {
                            if (areSpecificChannelsPresent) {
                                var payload = util_1.toType(args[0]);
                                if (R.isNil(payload.channel)) {
                                    SignalRChannel_1.logger.warn("[$SignalRChannel][onSignalRInitialize][" + channel_interface_1.CHANNEL_SEND_EVENT + "] A specific channel name is not defined. The params:", JSON.stringify(args));
                                }
                                else {
                                    var specificChannel = toChannelClient(payload.channel, channel_interface_1.CHANNEL_SEND_EVENT);
                                    if (!R.isNil(specificChannel)) {
                                        var dynamicMethods = Object.keys(specificChannel.server);
                                        if (!dynamicMethods.length) {
                                            SignalRChannel_1.logger.warn("[$SignalRChannel][onSignalRInitialize] There are no dynamic methods to execute! The hub: " + ip + ".");
                                        }
                                        else {
                                            if (dynamicMethods.length === 1) {
                                                SignalRChannel_1.logger.debug("[$SignalRChannel][onSignalRInitialize] The dynamic methods to execute are " + JSON.stringify(dynamicMethods) + "! The hub: " + ip + ".");
                                                (_a = specificChannel.server)[dynamicMethods[0]].apply(_a, payload.params);
                                            }
                                            else {
                                                SignalRChannel_1.logger.warn("[$SignalRChannel][onSignalRInitialize] There are more than one methods to execute! The hub: " + ip + ". The methods: " + JSON.stringify(dynamicMethods));
                                            }
                                        }
                                    }
                                }
                            }
                            else {
                                $.connection.hub.send(args[0]);
                            }
                        }
                        catch (e) {
                            SignalRChannel_1.logger.error("[$SignalRChannel][onSignalRInitialize] An error occurred during send a message! The hub: " + ip + ".", e);
                        }
                        break;
                }
            },
            close: function () {
                if (util_1.isFn(disconnectCallback)) {
                    disconnectCallback();
                }
                // See for details https://github.com/SignalR/SignalR/blob/master/src/Microsoft.AspNet.SignalR.JS/jquery.signalR.core.js#L887
                $($.connection.hub).off('onReceived');
                $.connection.hub.stop(false);
            },
        });
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     */
    SignalRChannel.prototype.cancelInitTask = function (ip) {
        if (this.signalRInitTasks.has(ip)) {
            this.signalRInitTasks.get(ip).cancel();
            this.signalRInitTasks.delete(ip);
        }
    };
    /**
     * @stable [17.12.2018]
     * @param {string} channelName
     * @param {string} event
     * @returns {IKeyValue}
     */
    SignalRChannel.prototype.toChannelClient = function (channelName, event) {
        var specificChannel = Reflect.get($.connection, channelName);
        if (R.isNil(specificChannel)) {
            SignalRChannel_1.logger.warn("[$SignalRChannel][toChannelClient][" + event + "] A specific channel is not defined by channel name " + (channelName || '[-]') + ". The event:", event);
        }
        return specificChannel;
    };
    var SignalRChannel_1;
    SignalRChannel.logger = ts_smart_logger_1.LoggerFactory.makeLogger('SignalRChannel');
    SignalRChannel = SignalRChannel_1 = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], SignalRChannel);
    return SignalRChannel;
}(base_channel_service_1.BaseChannel));
exports.SignalRChannel = SignalRChannel;
//# sourceMappingURL=signalr-channel.service.js.map