import * as React from 'react';
import { Store } from 'redux';
import { IKeyValue } from '../../definitions.interface';
import { DynamicRoutesMapT, IAuth, IDomAccessor, IEnvironment, IEventManager, IFieldConverter, IOperationEntity, IPermissionsManager, IPhoneConverter, IRoutesEntity, IUniversalContainer, IUniversalContainerProps, IUniversalStoreEntity, IUserActivityManager, TranslatorT } from '../../definition';
import { IDateConverter, INumberConverter } from '../../converter';
import { ISettingsEntity } from '../../settings';
import { IUIFactory } from '../factory/factory.interface';
export declare class UniversalContainer<TProps extends IUniversalContainerProps = IUniversalContainerProps, TState = {}, TAccessConfig = {}> extends React.PureComponent<TProps, TState> implements IUniversalContainer<TProps, TState> {
    protected readonly selfRef: React.RefObject<any>;
    /**
     * @stable - 12.04.2018
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [27.10.2019]
     * @param {string} type
     * @param {TData} data
     */
    dispatchCustomType<TData = IKeyValue>(type: string, data?: TData): void;
    /**
     * @stable [27.10.2019]
     * @param {string} type
     * @param {TData} data
     * @param {string} otherSectionName
     */
    dispatch<TData = IKeyValue>(type: string, data?: TData, otherSectionName?: string): void;
    /**
     * @deprecated Use proxy
     */
    dispatchFrameworkAction<TData = IKeyValue>(type: string, data?: TData, otherSection?: string): void;
    /**
     * @deprecated Use proxy
     */
    navigate<TPath0, TState0>(path: TPath0, state?: TState0): void;
    /**
     * @deprecated Use proxy
     */
    navigateAndRewrite<TPath0, TState0>(path: TPath0, state?: TState0): void;
    /**
     * @deprecated Use proxy
     */
    dispatchFormChanges<TChanges extends IKeyValue = IKeyValue>(changes: TChanges, otherSection?: string): void;
    /**
     * @deprecated Use proxy
     */
    dispatchLoadDictionary<TData = IKeyValue>(dictionary: string, data?: TData): void;
    /**
     * @deprecated Use proxy
     */
    protected navigateToBack(): void;
    /**
     * @deprecated Use TransportStoreProxy
     */
    protected isTransportOperationInProgress(operation: string | IOperationEntity): boolean;
    /**
     * @stable [16.11.2019]
     * @param {TAccessConfig} checkedObject
     * @returns {boolean}
     */
    protected hasPermission(checkedObject: TAccessConfig): boolean;
    /**
     * @stable - 15.04.2018
     * @returns {IRoutesEntity}
     */
    protected readonly routes: IRoutesEntity;
    /**
     * @deprecated Use proxy
     */
    private doNavigate;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {Store<IUniversalStoreEntity>}
     */
    protected readonly appStore: Store<IUniversalStoreEntity>;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {IPermissionsManager<TAccessConfig>}
     */
    protected readonly permissionsManager: IPermissionsManager<TAccessConfig>;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {TranslatorT}
     */
    protected readonly t: TranslatorT;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {IDateConverter}
     */
    protected readonly dc: IDateConverter;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {IFieldConverter}
     */
    protected readonly fieldConverter: IFieldConverter;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {ISettingsEntity}
     */
    protected readonly settings: ISettingsEntity;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {INumberConverter}
     */
    protected readonly nc: INumberConverter;
    /**
     * @react-native-compatible
     * @stable [19.02.2020]
     * @returns {IDomAccessor}
     */
    protected readonly domAccessor: IDomAccessor;
    /**
     * @react-native-compatible
     * @returns {IPhoneConverter}
     */
    protected readonly pc: IPhoneConverter;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {IUIFactory}
     */
    protected readonly uiFactory: IUIFactory;
    /**
     * @react-native-compatible
     * @stable [19.01.2020]
     * @returns {IUserActivityManager}
     */
    protected readonly userActivityManager: IUserActivityManager;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {IEnvironment}
     */
    protected readonly environment: IEnvironment;
    /**
     * @react-native-compatible
     * @stable [07.10.2019]
     * @returns {IEventManager}
     */
    protected readonly eventManager: IEventManager;
    /**
     * @react-native-compatible
     * @stable [16.11.2019]
     * @returns {IAuth}
     */
    protected readonly auth: IAuth;
    /**
     * @react-native-compatible
     * @stable [16.11.2019]
     * @returns {DynamicRoutesMapT}
     */
    protected readonly dynamicRoutes: DynamicRoutesMapT;
}
