/// <reference types="react" />
import { Field } from '../field';
import { IBaseTextField, IBaseTextFieldProps, IBaseTextFieldState } from './base-textfield.interface';
import { IFieldActionEntity, IKeyboardProps } from '../../../definition';
export declare class BaseTextField<TProps extends IBaseTextFieldProps, TState extends IBaseTextFieldState> extends Field<TProps, TState> implements IBaseTextField<TProps, TState> {
    private static readonly DEFAULT_MASK_GUIDE;
    private readonly mirrorInputRef;
    private readonly keyboardRef;
    private keyboardListenerUnsubscriber;
    /**
     * @stable [25.02.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [25.02.2019]
     * @returns {JSX.Element}
     */
    protected getInputElement(): JSX.Element;
    /**
     * @stable [24.10.2019]
     * @returns {string}
     */
    protected getSelfElementClassName(): string;
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    protected readonly keyboardElement: JSX.Element;
    /**
     * @stable [13.01.2019]
     * @returns {boolean}
     */
    protected isKeyboardOpen(): boolean;
    /**
     * @stable [02.02.2020]
     * @returns {IKeyboardProps}
     */
    protected getKeyboardProps(): IKeyboardProps;
    /**
     * @stable [02.02.2020]
     */
    protected openVirtualKeyboard(): void;
    /**
     * @stable [30.10.2019]
     */
    protected onCloseVirtualKeyboard(): void;
    /**
     * @stable [04.09.2018]
     */
    protected refreshCaretPosition(): void;
    /**
     * @stable [04.09.2018]
     * @returns {number}
     */
    protected getCaretPosition(): number;
    /**
     * @stable [23.10.2019]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    protected readonly progressLabelElement: JSX.Element;
    /**
     * @stable [12.09.2018]
     * @returns {JSX.Element}
     */
    protected getMirrorInputElement(): JSX.Element;
    protected getInputCaretElement(): JSX.Element;
    /**
     * @stable [15.09.2018]
     * @returns {JSX.Element}
     */
    protected readonly prefixLabelElement: JSX.Element;
    /**
     * @stable [28.10.2019]
     * @param {} action
     * @returns {boolean}
     */
    protected isFieldActionDisabled(action: IFieldActionEntity): boolean;
    /**
     * @stable [01.12.2019]
     * @returns {IFieldActionEntity[]}
     */
    protected getFieldActions(): IFieldActionEntity[];
    /**
     * @stable [16.02.2019]
     * @param {IBaseEvent} e
     */
    private onDocumentClickHandler;
    /**
     * @stable [04.09.2018]
     * @param {string} rawValue
     */
    private onKeyboardChange;
    /**
     * TODO domAccessor
     */
    private readonly jMirrorInput;
    /**
     * @stable [25.02.2019]
     * @returns {JSX.Element}
     */
    private getMaskedInputElement;
    /**
     * @stable [28.10.2019]
     * @returns {JSX.Element}
     */
    protected readonly actionsElement: JSX.Element;
    /**
     * @stable [30.10.2019]
     */
    private addClearAction;
    /**
     * @stable [02.02.2020]
     * @returns {boolean}
     */
    private readonly isKeyboardInline;
}
