/// <reference types="react" />
/// <reference types="googlemaps" />
import { BaseComponent } from '../../base';
import { IGoogleMaps, IGoogleMapsHeatMapLayerConfigEntity, IGoogleMapsMarkerConfigEntity, IGoogleMapsMenuContextEntity, IGoogleMapsProps } from '../../../definition';
export declare class GoogleMaps extends BaseComponent<IGoogleMapsProps> implements IGoogleMaps, IGoogleMapsMenuContextEntity {
    event: Event;
    lat: number;
    lng: number;
    private clickEventListener;
    private dbClickEventListener;
    private googleMapsLibTask;
    private heatMapLayer;
    private map;
    private markers;
    private markersListeners;
    private openMenuTask;
    private readonly menuRef;
    private wheelListenerUnsubscriber;
    private directionsService;
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsProps} props
     */
    constructor(props: IGoogleMapsProps);
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    render(): JSX.Element;
    /**
     * @stable [09.01.2020]
     */
    componentDidMount(): void;
    /**
     * @stable [22.01.2020]
     */
    componentWillUnmount(): void;
    /**
     * @stable [22.01.2020]
     * @param {google.maps.MarkerOptions} cfg
     * @param {string} name
     * @returns {google.maps.Marker}
     */
    addMarker(cfg?: google.maps.MarkerOptions, name?: string): google.maps.Marker;
    /**
     * @stable [03.03.2020]
     * @param {string} name
     */
    removeMarker(name: string): void;
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsMarkerConfigEntity} cfg
     */
    setMarkerState(cfg: IGoogleMapsMarkerConfigEntity): void;
    /**
     * @stable [23.02.2020]
     */
    addPolyline(polylineCfg: google.maps.PolylineOptions): google.maps.Polyline;
    /**
     * @stable [23.02.2020]
     */
    addDirectionPolyline(directionCfg: google.maps.DirectionsRequest, polylineCfg: google.maps.PolylineOptions): void;
    /**
     * @stable [04.03.2019]
     * @param {IGoogleMapsHeatMapLayerConfigEntity} cfg
     */
    addHeatMapLayer(cfg: IGoogleMapsHeatMapLayerConfigEntity): void;
    /**
     * @stable [20.02.2020]
     */
    fitBounds(bounds: google.maps.LatLngBounds | google.maps.LatLngBoundsLiteral, padding?: number | google.maps.Padding): void;
    /**
     * @stable [20.02.2020]
     */
    getMarkers(): Map<string, google.maps.Marker>;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    private readonly menuElement;
    /**
     * @stable [03.02.2020]
     * @param {IGoogleMapsEventEntity} event
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     */
    private onMarkerDragEnd;
    /**
     * @stable [03.02.2020]
     * @param {IGoogleMapsEventEntity} event
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     */
    private onMarkerClick;
    /**
     * @stable [03.02.2020]
     * @param {IGoogleMapsEventEntity} event
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     * @returns {IGoogleMapsMarkerPlaceEventEntity}
     */
    private asPlaceEventPayload;
    /**
     * @stable [10.01.2020]
     * @param {IMenuItemEntity} item
     */
    private onMenuSelect;
    /**
     * @stable [22.01.2020]
     * @param {IGoogleMapsEventEntity} payload
     */
    private onMapClick;
    /**
     * @stable [23.01.2020]
     * @param {IGoogleMapsEventEntity} event
     */
    private onMapDbClick;
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsMenuContextEntity} context
     */
    private openMenu;
    /**
     * @stable [22.01.2020]
     */
    private onGoogleMapsReady;
    /**
     * @stable [04.03.2019]
     * @param {ILatLngEntity} latLng
     * @param {number} zoom
     */
    private refreshMap;
    /**
     * @stable [09.01.2020]
     */
    private cancelGoogleMapsLibTask;
    /**
     * @stable [03.02.2020]
     * @param {string} eventName
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     * @param {() => void} callback
     */
    private addMakerListener;
    /**
     * @stable [22.01.2020]
     */
    private unbindListeners;
    /**
     * @stable [23.01.2020]
     * @returns {boolean}
     */
    private readonly haveMenuOptions;
    /**
     * @stable [04.03.2019]
     * @returns {IGoogleMapsSettingsEntity}
     */
    private readonly mapsSettings;
    /**
     * @stable [10.01.2020]
     * @returns {IMenu}
     */
    private readonly menu;
}
