"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var link_1 = require("../../link");
var definition_1 = require("../../../definition");
var universal_component_1 = require("../../base/universal.component");
var NavigationList = /** @class */ (function (_super) {
    __extends(NavigationList, _super);
    function NavigationList() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [24.10.2019]
     * @returns {JSX.Element}
     */
    NavigationList.prototype.render = function () {
        var items = this.props.items;
        return (React.createElement("nav", { ref: this.selfRef, className: 'rac-navigation-list' },
            this.getListDividerElement(),
            items.map(this.toElement, this)));
    };
    /**
     * @stable [07.02.2020]
     * @param {string} key
     * @returns {JSX.Element}
     */
    NavigationList.prototype.getListDividerElement = function (key) {
        return (React.createElement("div", { key: key, className: 'rac-list-divider' }));
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} item
     * @returns {JSX.Element}
     */
    NavigationList.prototype.toElement = function (item) {
        var _this = this;
        var isExpanded = this.isItemExpanded(item);
        var fullLayoutModeEnabled = this.isFullLayoutModeEnabled;
        var label = this.t(item.label);
        var ind = this.props.items.length - 1 -
            this.props.items.slice().reverse().findIndex(function (itm) { return itm.type === definition_1.NavigationItemTypesEnum.SUB_HEADER; });
        switch (item.type) {
            case definition_1.NavigationItemTypesEnum.SUB_HEADER:
                var isGroupItemActive = !isExpanded && this.hasActiveChild(item);
                return (React.createElement("div", { key: this.asUniqueKey(item.label, 'label'), className: util_1.joinClassName(this.buildItemClassNames(true, isGroupItemActive, isExpanded), ind === this.props.items.lastIndexOf(item) && !isExpanded && 'rac-navigation-list__last-section'), title: label, onClick: function () { return _this.onGroupLinkClick(item); } },
                    this.uiFactory.makeIcon({
                        key: this.asUniqueKey(item.label, 'group-icon'),
                        type: item.icon || 'list',
                    }),
                    fullLayoutModeEnabled && label,
                    fullLayoutModeEnabled && this.uiFactory.makeIcon({
                        key: this.asUniqueKey(item.label, 'group-expand-icon'),
                        type: isExpanded ? 'dropdown-opened' : 'dropdown',
                        className: 'rac-navigation-list__expand-icon',
                    })));
            case definition_1.NavigationItemTypesEnum.DIVIDER:
                return util_1.ifNotFalseThanValue(this.props.dividerRendered, function () { return _this.getListDividerElement(R.isNil(item.parent)
                    ? util_1.uuid()
                    : _this.asUniqueKey(item.parent.label, 'divider')); });
            default:
                var isGroup = R.isNil(item.parent);
                return util_1.orNull(isExpanded || isGroup, function () { return _this.asItemElement(item); });
        }
    };
    /**
     * @stable [12.02.2020]
     * @param {INavigationItemEntity} item
     * @returns {JSX.Element}
     */
    NavigationList.prototype.asItemElement = function (item) {
        var isFullLayoutModeEnabled = this.isFullLayoutModeEnabled;
        var label = this.t(item.label);
        var isGroup = R.isNil(item.parent);
        var isExpanded = this.isItemExpanded(item);
        return (React.createElement(link_1.Link, { to: item.link, key: this.asUniqueKey(item.link, 'link'), className: this.buildItemClassNames(isGroup, item.active, isExpanded), title: label },
            this.uiFactory.makeIcon({
                type: item.icon,
                key: this.asUniqueKey(item.link, 'icon'),
                className: 'rac-navigation-list__item-icon',
            }),
            isFullLayoutModeEnabled && label));
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} config
     */
    NavigationList.prototype.onGroupLinkClick = function (config) {
        var props = this.props;
        if (props.onGroupClick) {
            props.onGroupClick(config);
        }
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} item
     * @returns {boolean}
     */
    NavigationList.prototype.isItemExpanded = function (item) {
        var expandedGroups = this.props.expandedGroups;
        return expandedGroups[item.value] === true
            || (!R.isNil(item.parent) && expandedGroups[item.parent.value] === true);
    };
    Object.defineProperty(NavigationList.prototype, "isFullLayoutModeEnabled", {
        /**
         * @stable [23.09.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.layoutMode === definition_1.LayoutModesEnum.FULL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationList.prototype, "layoutMode", {
        get: function () {
            return util_1.nvl(this.systemLayoutMode, this.props.mode);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationList.prototype, "systemLayoutMode", {
        /**
         * @stable [04.02.2020]
         * @returns {LayoutModesEnum}
         */
        get: function () {
            return this.systemSettings.layoutMode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationList.prototype, "systemSettings", {
        /**
         * @stable [04.02.2020]
         * @returns {IDefaultLayoutProps}
         */
        get: function () {
            var _a = (this.settings.components || {}).defaultLayout, defaultLayout = _a === void 0 ? {} : _a;
            return defaultLayout;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.09.2018]
     * @param {INavigationItemEntity} item
     * @returns {boolean}
     */
    NavigationList.prototype.hasActiveChild = function (item) {
        var activeItem = R.find(function (itm) { return !!itm.active; }, this.props.items);
        return !R.isNil(activeItem) && !R.isNil(R.find(function (child) { return child.link === activeItem.link; }, item.children || []));
    };
    /**
     * @stable [07.02.2020]
     * @param {boolean} isGroup
     * @param {boolean} isActive
     * @param {boolean} isExpanded
     * @returns {string}
     */
    NavigationList.prototype.buildItemClassNames = function (isGroup, isActive, isExpanded) {
        return (util_1.joinClassName('rac-navigation-list__section', isGroup ? 'rac-navigation-list__group-section' : 'rac-navigation-list__item-section', isActive
            ? 'rac-navigation-list__active-section'
            : (isExpanded ? 'rac-navigation-list__expanded-section' : '')));
    };
    /**
     * @stable [07.02.2020]
     * @param {string} link
     * @param {string} prefix
     * @returns {string}
     */
    NavigationList.prototype.asUniqueKey = function (link, prefix) {
        return "navigation-list-key-" + link + "-" + prefix;
    };
    return NavigationList;
}(universal_component_1.UniversalComponent));
exports.NavigationList = NavigationList;
//# sourceMappingURL=navigation-list.component.js.map