"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var R = require("ramda");
var moment = require("moment");
require("moment-timezone");
var di_1 = require("../../di");
var util_1 = require("../../util");
var settings_1 = require("../../settings");
var definition_1 = require("../../definition");
var DateConverter = /** @class */ (function () {
    /**
     * @stable [22.01.2020]
     */
    function DateConverter() {
        this.appOnlineStartingDate = Date.now();
        this.environment.setVariable(definition_1.EnvironmentGlobalVariablesEnum.DATE_CONVERTER, this);
    }
    DateConverter_1 = DateConverter;
    Object.defineProperty(DateConverter.prototype, "appOnlineLifeTimeInSeconds", {
        /**
         * @stable [22.01.2020]
         * @returns {number}
         */
        get: function () {
            return Math.round((Date.now() - this.appOnlineStartingDate) * 0.001);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "appOnlineLifeTimeInHours", {
        /**
         * @stable [22.01.2020]
         * @returns {number}
         */
        get: function () {
            return Math.round(this.appOnlineLifeTimeInSeconds / 3600);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [08.01.2020]
     * @param {DateTimeLikeTypeT} date1
     * @param {DateTimeLikeTypeT} date2
     * @returns {number}
     */
    DateConverter.prototype.compare = function (date1, date2) {
        var date1$ = date1;
        var date2$ = date2;
        return R.equals(date1, date2)
            ? 0
            : (date1$ instanceof Date && date2$ instanceof Date
                ? date1$ === date2$ ? 0 : (date1$ > date2$ ? 1 : -1)
                : NaN);
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.format = function (date, inputFormat, outputFormat) {
        if (R.isNil(date) || R.isEmpty(date)) {
            return '';
        }
        else {
            var momentDate = this.toMomentDate(date, inputFormat);
            return momentDate.isValid()
                ? momentDate.format(outputFormat)
                : String(date);
        }
    };
    /**
     * @stable [22.12.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.dateAsString = function (cfg) {
        var date = cfg.date, outputFormat = cfg.outputFormat;
        if (date instanceof Date || util_1.isObjectNotEmpty(date)) {
            var momentDate = this.asMomentDate(cfg);
            return momentDate.isValid()
                ? momentDate.format(outputFormat)
                : String(date);
        }
        else {
            return '';
        }
    };
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asStartUnitOf = function (cfg) {
        return this.processValidMomentDate(__assign({ date: this.getCurrentDate() }, cfg), function (mDate) { return mDate.startOf(cfg.unit); });
    };
    /**
     * @stable [07.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {IDayOfYearEntity}
     */
    DateConverter.prototype.asDayOfYearEntity = function (cfg) {
        return this.processValidMomentDate(cfg, function (mDate) { return ({ day: mDate.date(), month: mDate.month(), year: mDate.year() }); });
    };
    /**
     * @stable [03.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asEndUnitOf = function (cfg) {
        return this.processValidMomentDate(__assign({ date: this.getCurrentDate() }, cfg), function (mDate) { return mDate.endOf(cfg.unit); });
    };
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asFirstDayOfWeek = function (cfg) {
        return this.asStartUnitOf(__assign({}, cfg, { unit: 'week' }));
    };
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asFirstDayOfMonth = function (cfg) {
        return this.asStartUnitOf(__assign({}, cfg, { unit: 'month' }));
    };
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asFirstDayOfQuarter = function (cfg) {
        return this.asStartUnitOf(__assign({}, cfg, { unit: 'quarter' }));
    };
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asFirstDayOfYear = function (cfg) {
        return this.asStartUnitOf(__assign({}, cfg, { unit: 'year' }));
    };
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asFirstDayOfWeekAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asFirstDayOfWeek(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [06.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asFirstDayOfMonthAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asFirstDayOfMonth(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asFirstDayOfQuarterAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asFirstDayOfQuarter(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asFirstDayOfYearAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asFirstDayOfYear(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asLastDayOfQuarter = function (cfg) {
        return this.asEndUnitOf(__assign({}, cfg, { unit: 'quarter' }));
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asLastDayOfQuarterAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asLastDayOfQuarter(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asLastDayOfMonth = function (cfg) {
        return this.asEndUnitOf(__assign({}, cfg, { unit: 'month' }));
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asLastDayOfMonthAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asLastDayOfMonth(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asLastDayOfWeek = function (cfg) {
        return this.asEndUnitOf(__assign({}, cfg, { unit: 'week' }));
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asLastDayOfWeekAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asLastDayOfWeek(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asLastDayOfYear = function (cfg) {
        return this.asEndUnitOf(__assign({}, cfg, { unit: 'year' }));
    };
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asLastDayOfYearAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.asLastDayOfYear(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.addDuration = function (cfg) {
        return this.processValidMomentDate(cfg, function (mDate) { return mDate.add(cfg.duration, cfg.unit); });
    };
    /**
     * @stable [06.01.2020]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {number}
     */
    DateConverter.prototype.asAbsoluteDayOfYear = function (cfg) {
        return this.processValidMomentDate(__assign({ date: this.getCurrentDate() }, cfg), function (mDate) { return mDate.dayOfYear(); });
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {moment.Moment}
     */
    DateConverter.prototype.addDays = function (cfg) {
        return this.addDuration(__assign({}, cfg, { unit: 'days' }));
    };
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.addDaysAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.addDays(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [03.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.addMonths = function (cfg) {
        return this.addDuration(__assign({}, cfg, { unit: 'months' }));
    };
    /**
     * @stable [06.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.addMonthsAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.addMonths(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [06.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.addQuartersAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.addQuarters(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.addQuarters = function (cfg) {
        return this.addDuration(__assign({}, cfg, { unit: 'quarters' }));
    };
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.addYears = function (cfg) {
        return this.addDuration(__assign({}, cfg, { unit: 'years' }));
    };
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.addYearsAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.addYears(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.addWeeks = function (cfg) {
        return this.addDuration(__assign({}, cfg, { unit: 'weeks' }));
    };
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.addWeeksAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.addWeeks(cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.addDaysToUiDate = function (cfg) {
        return this.addDays(__assign({}, cfg, { inputFormat: this.uiDateFormat }));
    };
    /**
     * @stable [02.01.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.addDaysToUiDateAsDate = function (cfg) {
        return util_1.ifNotNilThanValue(this.addDaysToUiDate(cfg), function (momentDate) { return momentDate.toDate(); });
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.fromDateTimeToArbitraryFormat = function (date, outputFormat) {
        return this.format(date, this.dateTimeFormat, outputFormat);
    };
    /**
     * @stable [04.03.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} outputFormat
     * @returns {string}
     */
    DateConverter.prototype.fromDateToArbitraryFormat = function (date, outputFormat) {
        return this.format(date, this.dateFormat, outputFormat);
    };
    /**
     * @stable [09.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.dateAsPstDateString = function (cfg) {
        return this.dateAsString(__assign({}, cfg, { outputFormat: this.pstDateFormat }));
    };
    /**
     * @stable [09.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.dateAsPstTimeString = function (cfg) {
        return this.dateAsString(__assign({}, cfg, { outputFormat: this.pstTimeFormat }));
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.fromDateTimeToPstTime = function (cfg) {
        return this.dateAsString(__assign({}, cfg, { inputFormat: this.dateTimeFormat, outputFormat: this.pstTimeFormat }));
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.fromDateTimeToDate = function (date) {
        return this.fromDateTimeToArbitraryFormat(date, this.dateFormat);
    };
    /**
     * @stable [25.12.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.fromDateTimeToUiDate = function (cfg) {
        return this.dateAsString(__assign({ inputFormat: this.dateTimeFormat, outputFormat: this.uiDateFormat }, cfg));
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.dateAsDateTimeString = function (cfg) {
        return this.dateAsString(__assign({}, cfg, { outputFormat: this.dateTimeFormat }));
    };
    /**
     * @stable [05.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.dateAsDateString = function (cfg) {
        return this.dateAsString(__assign({}, cfg, { outputFormat: this.dateFormat }));
    };
    /**
     * @stable [25.12.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.fromDateTimeToUiDateTime = function (cfg) {
        return this.dateAsString(__assign({ inputFormat: this.dateTimeFormat }, cfg, { outputFormat: (util_1.nvl(cfg.outputFormat, this.uiDateFormat) + " " + util_1.nvl(cfg.outputTimeFormat, this.uiTimeFormat))
                .trim() }));
    };
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: 2018-04-07T20:54:45+03:00]
     * @returns {string} [Example: 20:54:45]
     */
    DateConverter.prototype.fromDateTimeToTime = function (date) {
        return this.fromDateTimeToArbitraryFormat(date, this.timeFormat);
    };
    /**
     * @deptecated
     */
    DateConverter.prototype.fromDateTimeToDateTime = function (date) {
        return this.fromDateTimeToArbitraryFormat(date, this.dateTimeFormat);
    };
    /**
     * @stable [25.12.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.fromUiDateTimeToDateTime = function (cfg) {
        return this.dateAsString(__assign({ outputFormat: this.dateTimeFormat }, cfg, { date: (cfg.date + " " + util_1.nvl(cfg.time, this.uiDefaultTime)).trim(), inputFormat: (util_1.nvl(cfg.inputFormat, this.uiDateFormat) + " " + util_1.nvl(cfg.inputTimeFormat, this.uiTimeFormat))
                .trim() }));
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.fromUiDateToDateTime = function (cfg) {
        return this.dateAsString(__assign({}, cfg, { outputFormat: this.dateTimeFormat, inputFormat: this.uiDateFormat }));
    };
    /**
     * @stable [09.11.2018]
     * @param {TEntity} entity
     * @param {string} dateFieldName
     * @param {string} timeFieldName
     * @param {(entity: TEntity) => string} dateResolver
     * @returns {IKeyValue}
     */
    DateConverter.prototype.splitToDateTimeFields = function (entity, dateFieldName, timeFieldName, dateResolver) {
        var _this = this;
        var _a;
        var date = dateResolver(entity);
        return util_1.defValuesFilter((_a = {},
            _a[timeFieldName] = util_1.orUndef(date, function () { return _this.fromDateTimeToTime(date); }),
            _a[dateFieldName] = util_1.orUndef(date, function () { return _this.fromDateTimeToDate(date); }),
            _a));
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.tryConvertToDate = function (date, inputFormat) {
        if (inputFormat === void 0) { inputFormat = this.dateFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return momentDate.isValid() ? momentDate.toDate() : date;
    };
    /**
     * @stable [06.06.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {number}
     */
    DateConverter.prototype.tryConvertToDateAsTime = function (date, inputFormat) {
        if (inputFormat === void 0) { inputFormat = this.dateTimeFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return momentDate.isValid() ? momentDate.toDate().getTime() : -1;
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.tryAddXDurationAsMomentDate = function (unit, duration, date, inputFormat) {
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return util_1.orNull(momentDate.isValid(), function () { return momentDate.add(duration, unit); });
    };
    /**
     * @stable [11.08.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {number}
     */
    DateConverter.prototype.tryGetWeekdayNumber = function (date, inputFormat) {
        var _this = this;
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return util_1.orNull(momentDate.isValid(), function () { return _this.settings.dateTime.startDayOfWeek === settings_1.StartDayOfWeekT.MONDAY // TODO make getter
            ? momentDate.isoWeekday() : momentDate.weekday(); });
    };
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg2} unit
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryAddXDuration = function (unit, duration, date, inputFormat) {
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return util_1.ifNotNilThanValue(this.tryAddXDurationAsMomentDate(unit, duration, date, inputFormat), function (value) { return value.toDate(); });
    };
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryAddXDays = function (duration, date, inputFormat) {
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryAddXDuration('days', duration, date, inputFormat);
    };
    /**
     * @stable [07.01.2020]
     * @param {Date} date
     * @returns {Date}
     */
    DateConverter.prototype.asDayOfYear = function (date) {
        var d = new Date(date || this.getCurrentDate());
        d.setHours(0, 0, 0, 0);
        return d;
    };
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryAddXMonths = function (duration, date, inputFormat) {
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryAddXDuration('months', duration, date, inputFormat);
    };
    /**
     * @stable [10.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryAddXQuarters = function (duration, date, inputFormat) {
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryAddXDuration('quarters', duration, date, inputFormat);
    };
    /**
     * @stable [10.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryAddXYears = function (duration, date, inputFormat) {
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryAddXDuration('years', duration, date, inputFormat);
    };
    /**
     * @stable [09.02.2019]
     * @param {moment.DurationInputArg2} unit
     * @param {moment.unitOfTime.StartOf} startOf
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    DateConverter.prototype.tryGetFirstDayOfXAsMomentDate = function (unit, startOf, duration, date, inputFormat) {
        if (duration === void 0) { duration = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return util_1.ifNotNilThanValue(this.tryAddXDurationAsMomentDate(unit, duration, date, inputFormat), function (value) { return value.startOf(startOf); });
    };
    /**
     * @stable [08.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    DateConverter.prototype.tryGetFirstDayOfMonthAsMomentDate = function (duration, date, inputFormat) {
        if (duration === void 0) { duration = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryGetFirstDayOfXAsMomentDate('months', 'month', duration, date, inputFormat);
    };
    /**
     * @stable [10.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    DateConverter.prototype.tryGetFirstDayOfQuarterAsMomentDate = function (duration, date, inputFormat) {
        if (duration === void 0) { duration = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryGetFirstDayOfXAsMomentDate('quarters', 'quarter', duration, date, inputFormat);
    };
    /**
     * @stable [09.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    DateConverter.prototype.tryGetFirstDayOfWeekAsMomentDate = function (duration, date, inputFormat) {
        if (duration === void 0) { duration = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return this.tryGetFirstDayOfXAsMomentDate('weeks', this.settings.dateTime.startDayOfWeek === settings_1.StartDayOfWeekT.MONDAY ? 'isoWeek' : 'week', duration, date, inputFormat);
    };
    /**
     * @stable [09.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryGetFirstDayOfWeek = function (duration, date, inputFormat) {
        if (duration === void 0) { duration = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return util_1.ifNotNilThanValue(this.tryGetFirstDayOfWeekAsMomentDate(duration, date, inputFormat), function (value) { return value.toDate(); });
    };
    /**
     * @stable [08.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.tryGetFirstDayOfMonth = function (duration, date, inputFormat) {
        if (duration === void 0) { duration = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.uiDateFormat; }
        return util_1.ifNotNilThanValue(this.tryGetFirstDayOfMonthAsMomentDate(duration, date, inputFormat), function (value) { return value.toDate(); });
    };
    /**
     * @stable [08.08.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {boolean}
     */
    DateConverter.prototype.isDateBelongsToCurrentWeek = function (date, inputFormat) {
        if (inputFormat === void 0) { inputFormat = this.dateFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return momentDate.isValid() && (momentDate.toDate() >= this.tryGetFirstDayOfWeek());
    };
    /**
     * @stable [22.12.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.fromDateToUiDate = function (cfg) {
        return this.dateAsString(__assign({ strict: false, inputFormat: this.dateFormat, outputFormat: this.uiDateFormat }, cfg));
    };
    /**
     * @stable [08.01.2020]
     * @param {IDayOfYearEntity} entity
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.fromDayOfYearEntity = function (entity, cfg) {
        var mDate = this.asMomentDate(__assign({ date: this.asDayOfYear() }, cfg));
        if (util_1.isNumber(entity.month)) {
            mDate.month(entity.month);
        }
        if (util_1.isNumber(entity.year)) {
            mDate.year(entity.year);
        }
        if (util_1.isNumber(entity.day)) {
            mDate.date(entity.day);
        }
        return util_1.orNull(mDate.isValid(), function () { return mDate; });
    };
    /**
     * @stable [08.01.2020]
     * @param {IDayOfYearEntity} entity
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.fromDayOfYearEntityAsDate = function (entity, cfg) {
        return util_1.ifNotNilThanValue(this.fromDayOfYearEntity(entity, cfg), function (mDate) { return mDate.toDate(); });
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.get30DaysAgo = function () {
        return this.getXDaysAgo(30);
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.getXDaysAgo = function (days) {
        return this.getCurrentMomentDate().subtract(days, 'days').toDate();
    };
    /**
     * @stable [25.12.2019]
     * @tested
     * @returns {Date}
     */
    DateConverter.prototype.getCurrentDate = function () {
        return this.currentDate;
    };
    /**
     * @stable [25.12.2019]
     * @returns {string}
     */
    DateConverter.prototype.getCurrentDateAsUiDate = function () {
        return this.dateAsString({ date: this.getCurrentDate(), outputFormat: this.uiDateFormat });
    };
    DateConverter.prototype.getLocalizedMonth = function (index) {
        return DateConverter_1.MONTHS[index];
    };
    DateConverter.prototype.getLocalizedMonthShort = function (index) {
        return DateConverter_1.MONTHS_SHORT[index];
    };
    DateConverter.prototype.getLocalizedWeekday = function (index) {
        return DateConverter_1.WEEKDAYS[index];
    };
    DateConverter.prototype.getLocalizedWeekdayShort = function (index) {
        return DateConverter_1.WEEKDAYS_SHORT[index];
    };
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string[]}
     */
    DateConverter.prototype.getShortestWeekdays = function (cfg) {
        var _a = (cfg || {}).isoWeek, isoWeek = _a === void 0 ? false : _a;
        return isoWeek
            ? DateConverter_1.DEFAULT_SHORTEST_ISO_WEEKDAYS
            : DateConverter_1.DEFAULT_SHORTEST_WEEKDAYS;
    };
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string[]}
     */
    DateConverter.prototype.getLocalizedShortestWeekdays = function (cfg) {
        // TODO Localize
        return this.getShortestWeekdays(cfg);
    };
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.getShortestWeekday = function (cfg) {
        return this.getShortestWeekdays(cfg)[cfg.index];
    };
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    DateConverter.prototype.getLocalizedShortestWeekday = function (cfg) {
        return this.getLocalizedShortestWeekdays(cfg)[cfg.index];
    };
    /**
     * @stable [25.08.2018]
     * @param {number} monthsAgo
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.getLastDayOfMonth = function (monthsAgo, date, inputFormat) {
        if (monthsAgo === void 0) { monthsAgo = 1; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.dateTimeSettings.uiDateFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return util_1.orNull(momentDate.isValid(), function () { return momentDate.subtract(monthsAgo, 'months').endOf('month').toDate(); });
    };
    /**
     * @stable [25.08.2018]
     * @param {number} monthsAgo
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.getFirstDayOfMonth = function (monthsAgo, date, inputFormat) {
        if (monthsAgo === void 0) { monthsAgo = 0; }
        if (date === void 0) { date = this.currentDate; }
        if (inputFormat === void 0) { inputFormat = this.dateTimeSettings.uiDateFormat; }
        var momentDate = this.toMomentDate(date, inputFormat);
        return util_1.orNull(momentDate.isValid(), function () { return momentDate.subtract(monthsAgo, 'months').startOf('month').toDate(); });
    };
    /**
     * @stable [22.01.2020]
     * @param {IPersonAgeConfigEntity} cfg
     * @returns {number}
     */
    DateConverter.prototype.asPersonAge = function (cfg) {
        return this.processValidMomentDate(__assign({ date: this.getCurrentDate(), inputFormat: this.uiDateFormat }, cfg), function (mDate) { return mDate.diff(cfg.birthday, 'years'); });
    };
    DateConverter.prototype.isSameMonth = function (date1, date2) {
        return (date1.getMonth() === date2.getMonth() &&
            date1.getFullYear() === date2.getFullYear());
    };
    DateConverter.prototype.isSameDay = function (date1, date2) {
        return this.isSameMonth(date1, date2) && date1.getDate() === date2.getDate();
    };
    DateConverter.prototype.isWeekend = function (day) {
        return day === 0 || day === 6;
    };
    /**
     * @stable [24.11.2018]
     * @param {string} dateAsString
     * @param {string} timeAsString
     * @returns {string}
     */
    DateConverter.prototype.combine = function (dateAsString, timeAsString) {
        return [dateAsString, timeAsString].join(' ');
    };
    /**
     * @stable [03.04.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {Date}
     */
    DateConverter.prototype.toDate = function (date, inputFormat) {
        return this.toMomentDate(date, inputFormat).toDate();
    };
    /**
     * @deprecated Use asMomentDate
     */
    DateConverter.prototype.toMomentDate = function (date, inputFormat, strict) {
        if (strict === void 0) { strict = true; }
        var momentDate = date instanceof Date
            ? moment(date)
            : moment(date, inputFormat, strict);
        var zone = this.timeZone;
        return zone ? moment.tz(date, zone) : momentDate;
    };
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    DateConverter.prototype.asMomentDate = function (cfg) {
        var date = cfg.date, inputFormat = cfg.inputFormat, _a = cfg.strict, strict = _a === void 0 ? true : _a, _b = cfg.zone, zone = _b === void 0 ? this.timeZone : _b;
        if (moment.isMoment(date)) {
            return date;
        }
        return zone
            ? (date instanceof Date
                ? moment.tz(date, zone)
                : moment.tz(date, inputFormat, strict, zone))
            : (date instanceof Date
                ? moment(date)
                : moment(date, inputFormat, strict));
    };
    /**
     * @stable [07.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    DateConverter.prototype.asDate = function (cfg) {
        return this.processValidMomentDate(cfg, function (mDate) { return mDate.toDate(); });
    };
    /**
     * @stable [07.01.2020]
     * @tested
     * @param {IDayOfYearEntity} o1
     * @param {IDayOfYearEntity} o2
     * @returns {number}
     */
    DateConverter.prototype.compareDayOfYearEntity = function (o1, o2) {
        o1 = o1 || {};
        o2 = o2 || {};
        return this.compare(this.fromDayOfYearEntityAsDate(o1), this.fromDayOfYearEntityAsDate(o2));
    };
    /**
     * @stable [07.01.2020]
     * @tested
     * @param {IFromToDayOfYearEntity} range
     * @param {IDayOfYearEntity} entity
     * @returns {IFromToDayOfYearEntity}
     */
    DateConverter.prototype.selectDaysOfYearRange = function (range, entity) {
        var _a = range || {}, _b = _a.to, to = _b === void 0 ? {} : _b, _c = _a.from, from = _c === void 0 ? {} : _c;
        var day = entity.day, month = entity.month, year = entity.year;
        var onlyFrom = entity.from === true;
        var onlyTo = entity.to === true;
        var isDateToEmpty = R.isEmpty(to);
        var isDateFromEmpty = R.isEmpty(from);
        if (onlyFrom) { // Manual set
            return { to: to, from: { day: day, month: month, year: year } };
        }
        else if (onlyTo) { // Manual set
            return { from: from, to: { day: day, month: month, year: year } };
        }
        if (isDateToEmpty && isDateFromEmpty) {
            return ({ from: { day: day, month: month, year: year }, to: to });
        }
        else if (!isDateFromEmpty && !isDateToEmpty) {
            return ({ from: { day: day, month: month, year: year }, to: {} });
        }
        else if (!isDateFromEmpty) {
            var compareResult = this.compareDayOfYearEntity(from, entity);
            if (compareResult >= 0) {
                return ({ from: compareResult === 0 ? {} : { day: day, month: month, year: year }, to: to });
            }
            else {
                return ({ from: from, to: { day: day, month: month, year: year } });
            }
        }
        else if (!isDateToEmpty) {
            // The "from value" is not set
            var compareResult = this.compareDayOfYearEntity(entity, to);
            if (compareResult >= 0) {
                return ({ from: compareResult === 0 ? {} : __assign({}, to), to: { day: day, month: month, year: year } });
            }
            else {
                return ({ from: { day: day, month: month, year: year }, to: to });
            }
        }
        return ({ from: from, to: to });
    };
    /**
     * @stable [08.01.2020]
     * @param {IMinMaxDatesRangeConfigEntity} cfg
     * @returns {boolean}
     */
    DateConverter.prototype.isDateBelongToDatesRange = function (cfg) {
        var minDate = util_1.nvl(cfg.minDate, this.dateTimeSettings.minDate);
        var maxDate = util_1.nvl(cfg.maxDate, this.dateTimeSettings.maxDate);
        return this.compare(cfg.date, minDate) >= 0 && this.compare(maxDate, cfg.date) >= 0;
    };
    /**
     * @stable [07.01.2020]
     * @tested
     * @param {IFromToDayOfYearEntity} range
     * @param {IDayOfYearEntity} entity
     * @returns {boolean}
     */
    DateConverter.prototype.isDayOfYearBelongToDaysOfYearRange = function (range, entity) {
        var _a = range.from, from = _a === void 0 ? {} : _a, _b = range.to, to = _b === void 0 ? {} : _b;
        var isDateToEmpty = R.isEmpty(to);
        var isDateFromEmpty = R.isEmpty(from);
        if (!isDateFromEmpty && isDateToEmpty) {
            return this.compareDayOfYearEntity(entity, from) === 0;
        }
        if (isDateFromEmpty && !isDateToEmpty) {
            return this.compareDayOfYearEntity(entity, to) === 0;
        }
        if (!isDateToEmpty && !isDateFromEmpty) {
            var compareResult1 = this.compareDayOfYearEntity(entity, from);
            var compareResult2 = this.compareDayOfYearEntity(entity, to);
            return compareResult1 >= 0 && compareResult2 <= 0;
        }
        return false;
    };
    /**
     * @stable [07.03.2020]
     * @param {IDayOfYearEntity} entity1
     * @param {IDayOfYearEntity} entity2
     * @returns {boolean}
     */
    DateConverter.prototype.isDayOfYearEqualOtherDayOfYear = function (entity1, entity2) {
        return !R.isNil(entity1) && !R.isNil(entity2)
            && (entity1.day === entity2.day
                && entity1.month === entity2.month
                && entity1.year === entity2.year);
    };
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {ICalendarEntity}
     */
    DateConverter.prototype.asCalendar = function (cfg) {
        var _this = this;
        var syntheticCalendar = util_1.ifNotNilThanValue(cfg, function () { return cfg.useSyntheticCalendar === true; }, false);
        cfg = __assign({ isoWeek: syntheticCalendar || false }, cfg, (syntheticCalendar ? ({ date: new Date('01/01/1900') }) : ({}) // The date "01/01/1900" starts on Monday.
        ));
        var isoWeek = cfg.isoWeek;
        var firstDayOfMonthAsMDate = this.asFirstDayOfMonth(cfg);
        var firstDayOfIsoWeek = firstDayOfMonthAsMDate.isoWeekday();
        var maxWeeksCount = 6;
        var maxDaysCountOnWeek = 7;
        var today = this.asDayOfYear();
        var data = [];
        var currentDate;
        var currentMonthValue;
        var dayEntity;
        var buildDayEntity = function (itm, mDate) { return (__assign({ current: false, next: false, previous: false }, itm, { day: mDate.date(), month: mDate.month(), today: _this.compare(today, mDate.toDate()) === 0, year: mDate.year() })); };
        for (var i = 0; i < maxWeeksCount; i++) {
            var row = { id: i };
            data.push(row);
            for (var j = 0; j < maxDaysCountOnWeek; j++) {
                if (R.isNil(currentDate)) {
                    if (firstDayOfIsoWeek === j + 1) { // The ISO day of the week: 1 === Monday and 7 === Sunday
                        currentDate = firstDayOfMonthAsMDate.toDate();
                        currentMonthValue = firstDayOfMonthAsMDate.month();
                        dayEntity = buildDayEntity({ current: true, date: currentDate }, firstDayOfMonthAsMDate);
                        row[j] = dayEntity;
                        for (var k = j - 1, m = 1; k >= 0; k--) {
                            var mDate = this.addDays({ date: currentDate, duration: -1 * m++ });
                            dayEntity = buildDayEntity({ previous: true, date: mDate.toDate() }, mDate);
                            row[k] = dayEntity;
                        }
                    }
                }
                else {
                    var currentMDate = this.addDays({ date: currentDate, duration: 1 });
                    currentDate = currentMDate.toDate();
                    var next = currentMDate.month() !== currentMonthValue;
                    dayEntity = buildDayEntity({ current: !next, next: next, date: currentDate }, currentMDate);
                    row[j] = dayEntity;
                }
            }
        }
        var result = {
            days: data,
            daysLabels: this.getLocalizedShortestWeekdays(cfg),
        };
        if (!isoWeek) {
            result.days = data.map(function (row, index) {
                var newRow = __assign({}, row);
                for (var i = 0; i < maxDaysCountOnWeek - 1; i++) {
                    newRow[i + 1] = row[i];
                }
                var startingDate = data[index - 1];
                if (R.isNil(startingDate)) {
                    var startingMDate = _this.addDays({ date: data[0][0].date, duration: -1 });
                    dayEntity = buildDayEntity({ previous: true, date: startingMDate.toDate() }, startingMDate);
                    newRow[0] = dayEntity;
                }
                else {
                    newRow[0] = data[index - 1][maxDaysCountOnWeek - 1];
                }
                return newRow;
            });
        }
        var truncateFirstWeek = true;
        var truncateLastWeek = true;
        var days = result.days;
        for (var j = 0; j < maxDaysCountOnWeek; j++) {
            truncateFirstWeek = truncateFirstWeek && days[0][j].current === false;
            truncateLastWeek = truncateLastWeek && days[days.length - 1][j].current === false;
        }
        return __assign({}, result, { days: (truncateFirstWeek ? [] : [days[0]]).concat(days.slice(1, days.length - 1), (truncateLastWeek ? [] : [days[days.length - 1]])) });
    };
    /**
     * @stable [03.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @param {(date: MomentT) => TResult} handler
     * @returns {TResult}
     */
    DateConverter.prototype.processValidMomentDate = function (cfg, handler) {
        var momentDate = this.asMomentDate(cfg);
        return util_1.orNull(momentDate.isValid(), function () { return handler(momentDate); });
    };
    /**
     * @deprecated
     */
    DateConverter.prototype.getCurrentMomentDate = function () {
        return this.toMomentDate(this.currentDate);
    };
    Object.defineProperty(DateConverter.prototype, "timeZone", {
        /**
         * @stable [11.08.2018]
         * @returns {string}
         */
        get: function () {
            return this.dateTimeSettings.timeZone;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "currentDate", {
        /**
         * @stable [25.12.2019]
         * @returns {Date}
         */
        get: function () {
            return this.dateTimeSettings.currentDate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "dateTimeFormat", {
        get: function () {
            return this.dateTimeSettings.dateTimeFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "dateFormat", {
        get: function () {
            return this.dateTimeSettings.dateFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "timeFormat", {
        get: function () {
            return this.dateTimeSettings.timeFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "uiDateFormat", {
        get: function () {
            return this.dateTimeSettings.uiDateFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "uiTimeFormat", {
        /**
         * @stable [25.12.2019]
         * @returns {string}
         */
        get: function () {
            return this.dateTimeSettings.uiTimeFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "uiDefaultTime", {
        /**
         * @stable [25.12.2019]
         * @returns {string}
         */
        get: function () {
            return this.dateTimeSettings.uiDefaultTime;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "pstTimeFormat", {
        /**
         * @stable [02.01.2019]
         * @returns {string}
         */
        get: function () {
            return this.dateTimeSettings.pstTimeFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "pstDateFormat", {
        get: function () {
            return this.dateTimeSettings.pstDateFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateConverter.prototype, "dateTimeSettings", {
        get: function () {
            return this.settings.dateTime || {};
        },
        enumerable: true,
        configurable: true
    });
    var DateConverter_1;
    DateConverter.MONTHS = moment.months();
    DateConverter.MONTHS_SHORT = moment.monthsShort();
    DateConverter.WEEKDAYS_SHORT = moment.weekdaysShort()
        .slice(1, 7)
        .concat(moment.weekdaysShort()[0]);
    DateConverter.WEEKDAYS = moment.weekdays()
        .slice(1, 7)
        .concat(moment.weekdays()[0]);
    DateConverter.DEFAULT_SHORTEST_ISO_WEEKDAYS = ['M', 'T', 'W', 'TH', 'F', 'SA', 'SU'];
    DateConverter.DEFAULT_SHORTEST_WEEKDAYS = [
        DateConverter_1.DEFAULT_SHORTEST_ISO_WEEKDAYS[6]
    ].concat(DateConverter_1.DEFAULT_SHORTEST_ISO_WEEKDAYS.slice(0, 6));
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Environment),
        __metadata("design:type", Object)
    ], DateConverter.prototype, "environment", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Settings),
        __metadata("design:type", Object)
    ], DateConverter.prototype, "settings", void 0);
    DateConverter = DateConverter_1 = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], DateConverter);
    return DateConverter;
}());
exports.DateConverter = DateConverter;
//# sourceMappingURL=date-converter.service.js.map