"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var di_1 = require("../../di");
var dateConverter = di_1.getDateConverter();
describe('date-converter.service', function () {
    describe('fromUiDateTimeToDateTime', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromUiDateTimeToDateTime({ date: '2036-07-31', time: '22:56:33' });
            expect(value).toEqual('2036-07-31T22:56:33-07:00');
        });
        it('test2', function () {
            var value = dateConverter.fromUiDateTimeToDateTime({ date: '2036-07-31', time: '22:56', strict: false });
            expect(value).toEqual('2036-07-31T22:56:00-07:00');
        });
        it('test3', function () {
            var value = dateConverter.fromUiDateTimeToDateTime({ date: '2036-07-31', time: '22', strict: false });
            expect(value).toEqual('2036-07-31T22:00:00-07:00');
        });
        it('test4', function () {
            var value = dateConverter.fromUiDateTimeToDateTime({ date: '2036-07-31' });
            expect(value).toEqual('2036-07-31T00:00:00-07:00');
        });
    });
    describe('fromDateToUiDate', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromDateToUiDate({ date: '2036-07-31' });
            expect(value).toEqual('2036-07-31');
        });
        it('test2', function () {
            var value = dateConverter.fromDateToUiDate({ date: '2036-07-31T00:00:00Z' });
            expect(value).toEqual('2036-07-31');
        });
    });
    describe('fromDateTimeToUiDate', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromDateTimeToUiDate({ date: '2036-07-31T00:00:00+03:00' }); // Moscow, Russia
            expect(value).toEqual('2036-07-30'); // Los Angeles, USA
        });
        it('test2', function () {
            var value = dateConverter.fromDateTimeToUiDate({ date: '2036-07-31T05:00:00+03:00' }); // Moscow, Russia
            expect(value).toEqual('2036-07-30'); // Los Angeles, USA
        });
        it('test3', function () {
            var value = dateConverter.fromDateTimeToUiDate({ date: new Date('2036-07-31T05:00:00+03:00') }); // Moscow, Russia
            expect(value).toEqual('2036-07-30'); // Los Angeles, USA
        });
    });
    describe('fromDateTimeToUiDateTime', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromDateTimeToUiDateTime({ date: '2036-07-31T00:00:00+03:00' }); // Moscow, Russia
            expect(value).toEqual('2036-07-30 14:00:00'); // Los Angeles, USA
        });
        it('test2', function () {
            var value = dateConverter.fromDateTimeToUiDateTime({
                date: '2036-07-31T00:23:34+03:00',
                outputTimeFormat: 'HH:mm',
            });
            expect(value).toEqual('2036-07-30 14:23'); // Los Angeles, USA
        });
    });
    describe('getCurrentDate', function () {
        it('test1', function () {
            var value = dateConverter.getCurrentDate();
            expect(value).toEqual(new Date('Aug 30 2036 00:00:00 GMT-0800'));
        });
    });
    describe('addDaysToUiDateAsDate', function () {
        it('test1', function () {
            var value = dateConverter.addDaysToUiDateAsDate({ date: '2020-01-31', duration: 1 });
            expect(value).toEqual(new Date('February 1 2020 00:00:00 GMT-0800'));
        });
        it('test2', function () {
            var value = dateConverter.addDaysToUiDateAsDate({ date: '2020-02-29', duration: 1 });
            expect(value).toEqual(new Date('March 1 2020 00:00:00 GMT-0800'));
        });
    });
    describe('asAbsoluteDayOfYear', function () {
        it('test1', function () {
            var value = dateConverter.asAbsoluteDayOfYear({ date: '2020-02-29', inputFormat: 'YYYY-MM-DD' });
            expect(value).toEqual(60);
        });
        it('test2', function () {
            var value = dateConverter.asAbsoluteDayOfYear({ date: new Date('February 29 2020 00:00:00 GMT-0800') });
            expect(value).toEqual(60);
        });
        it('test3', function () {
            var value = dateConverter.asAbsoluteDayOfYear();
            expect(value).toEqual(243);
        });
    });
    describe('compareDayOfYearEntity', function () {
        it('test1', function () {
            var value = dateConverter.compareDayOfYearEntity({ year: 2019, month: 2, day: 23 }, { year: 2019, month: 2, day: 23 });
            expect(value).toEqual(0);
        });
        it('test2', function () {
            var value = dateConverter.compareDayOfYearEntity({ year: 2016, month: 2, day: 29 }, { year: 2016, month: 3, day: 1 });
            expect(value).toEqual(-1);
        });
        it('test3', function () {
            var value = dateConverter.compareDayOfYearEntity({ year: 2016, month: 3, day: 1 }, { year: 2016, month: 2, day: 29 });
            expect(value).toEqual(1);
        });
    });
    describe('selectDaysOfYearRange', function () {
        it('test1 [] -> [from]', function () {
            var value = dateConverter.selectDaysOfYearRange({}, { year: 2016, month: 2, day: 29 });
            expect(value).toEqual({ to: {}, from: { year: 2016, month: 2, day: 29 } });
        });
        it('test2 [<-from]', function () {
            var value = dateConverter.selectDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 } }, { year: 2016, month: 2, day: 28 });
            expect(value).toEqual({ to: {}, from: { year: 2016, month: 2, day: 28 } });
        });
        it('test3 [from] -> []', function () {
            var value = dateConverter.selectDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 } }, { year: 2016, month: 2, day: 29 });
            expect(value).toEqual({ to: {}, from: {} });
        });
        it('test4 [from] -> [from, to]', function () {
            var value = dateConverter.selectDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 } }, { year: 2016, month: 3, day: 1 });
            expect(value).toEqual({ to: { year: 2016, month: 3, day: 1 }, from: { year: 2016, month: 2, day: 29 } });
        });
        it('test5 [from, to]->[from]', function () {
            var value = dateConverter.selectDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 3, day: 1 });
            expect(value).toEqual({ from: { year: 2016, month: 3, day: 1 }, to: {} });
        });
        it('test6 [to]->[from, to]', function () {
            var value = dateConverter.selectDaysOfYearRange({ from: {}, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 2, day: 29 });
            expect(value).toEqual({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } });
        });
        it('test7 [to]->[from, to]', function () {
            var value = dateConverter.selectDaysOfYearRange({ from: {}, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 3, day: 3 });
            expect(value).toEqual({ from: { year: 2016, month: 3, day: 2 }, to: { year: 2016, month: 3, day: 3 } });
        });
    });
    describe('isDayOfYearBelongToDaysOfYearRange', function () {
        it('test1', function () {
            var value = dateConverter.isDayOfYearBelongToDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 3, day: 1 });
            expect(value).toEqual(true);
        });
        it('test2', function () {
            var value = dateConverter.isDayOfYearBelongToDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 2, day: 29 });
            expect(value).toEqual(true);
        });
        it('test3', function () {
            var value = dateConverter.isDayOfYearBelongToDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 3, day: 2 });
            expect(value).toEqual(true);
        });
        it('test4', function () {
            var value = dateConverter.isDayOfYearBelongToDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 2, day: 28 });
            expect(value).toEqual(false);
        });
        it('test5', function () {
            var value = dateConverter.isDayOfYearBelongToDaysOfYearRange({ from: { year: 2016, month: 2, day: 29 }, to: { year: 2016, month: 3, day: 2 } }, { year: 2016, month: 3, day: 3 });
            expect(value).toEqual(false);
        });
    });
});
//# sourceMappingURL=date-converter.service.spec.js.map