"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var wrapper_1 = require("./wrapper");
var type_1 = require("./type");
var nvl_1 = require("./nvl");
var mapper_1 = require("./mapper");
var object_1 = require("./object");
/**
 * [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @param {IGenericBaseFieldEntity} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldValue = function (entity, fieldProps) {
    return type_1.isDef(fieldProps.value)
        ? fieldProps.value
        : (cond_1.ifNotEmptyThanValue(fieldProps.name, function (fieldName) { return cond_1.ifNotNilThanValue(R.isNil(entity.entity)
            ? cond_1.ifNotNilThanValue(entity.form, function (form) { return form.changes; })
            : entity.entity, function (data) { return Reflect.get(data, fieldName); }, definitions_interface_1.UNDEF_SYMBOL); }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @param {IGenericBaseFieldEntity} fieldProps
 * @param {IGenericBaseFieldEntity} defaultFieldProps
 * @returns {AnyT}
 */
exports.getFormFieldDisplayValue = function (entity, fieldProps, defaultFieldProps) {
    return type_1.isDef(fieldProps.displayValue)
        ? fieldProps.displayValue
        : (cond_1.ifNotEmptyThanValue(fieldProps.displayName || cond_1.ifNotNilThanValue(defaultFieldProps, function () { return defaultFieldProps.displayName; }), function (displayName) { return cond_1.ifNotNilThanValue(R.isNil(entity.entity)
            ? cond_1.ifNotNilThanValue(entity.form, function (form) { return form.changes; }) // TODO Select form changes
            : entity.entity, function (data) { return Reflect.get(data, displayName); }, definitions_interface_1.UNDEF_SYMBOL); }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @param {IGenericBaseFieldEntity} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldOriginalValue = function (entity, fieldProps) {
    return type_1.isDef(fieldProps.originalValue)
        ? fieldProps.originalValue
        : (cond_1.ifNotNilThanValue(entity.originalEntity, function (originalEntity) {
            return cond_1.ifNotEmptyThanValue(fieldProps.name, function (fieldName) { return Reflect.get(originalEntity, fieldName); }, definitions_interface_1.UNDEF_SYMBOL);
        }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormDisabled = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return wrapper_1.isDisabled(entity) || exports.isFormInProgress(entity); }, false);
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return (wrapper_1.isAlwaysDirty(entity) || (cond_1.ifNotNilThanValue(mapper_1.selectEditableEntity(entity), function (form) { return wrapper_1.isDirty(form) || object_1.isObjectNotEmpty(form.defaultChanges); }, false))); }, false);
};
/**
 * @stable [16.01.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormValid = function (entity) {
    return wrapper_1.isValid(entity) && wrapper_1.isValid(mapper_1.selectEditableEntity(entity));
}; // Redux or auto validation
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormInProgress = function (entity) {
    return wrapper_1.inProgress(mapper_1.selectEditableEntity(entity));
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} formEntity
 * @param {IGenericBaseFieldEntity} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldReadOnly = function (formEntity, fieldProps) {
    return nvl_1.nvl(cond_1.ifNotNilThanValue(fieldProps, function () { return fieldProps.readOnly; }), cond_1.ifNotNilThanValue(formEntity, function () { return formEntity.readOnly; })) === true;
};
/**
 * @stable [03.02.2020]
 * @param {IFormProps<TEntity extends IEntity>} formProps
 * @returns {boolean}
 */
exports.isFormSubmittable = function (formProps) {
    return exports.isFormValid(formProps)
        && exports.isFormDirty(formProps)
        && !exports.isFormDisabled(formProps);
};
//# sourceMappingURL=form.js.map